@@ -11,12 +11,19 @@ from ..genome import mm10
 class BROAD(AutoPathMixIn):
     def __init__(self):
         self.BROAD_TENX_SAMPLE_METADATA_PATH = BROAD_TENX_SAMPLE_METADATA_PATH
+
         self.BROAD_TENX_ZARR_PATH = BROAD_TENX_ZARR_PATH
+        self.BROAD_TENX_V2_ZARR_PATH = BROAD_TENX_V2_ZARR_PATH
+
         self.BROAD_TENX_OUTLIER_IDS_PATH = BROAD_TENX_OUTLIER_IDS_PATH
+
         self.BROAD_TENX_CELL_TYPE_ANNOTATION_PATH = BROAD_TENX_CELL_TYPE_ANNOTATION_PATH
+        self.BROAD_TENX_CELL_TYPE_V2_ANNOTATION_PATH = BROAD_TENX_CELL_TYPE_V2_ANNOTATION_PATH
+
         self.BROAD_TENX_GENE_MAP_PATH = BROAD_TENX_GENE_MAP_PATH
 
         self.BROAD_TENX_GENE_CHUNK_ZARR_PATH = BROAD_TENX_GENE_CHUNK_ZARR_PATH
+        self.BROAD_TENX_GENE_CHUNK_V2_ZARR_PATH = BROAD_TENX_GENE_CHUNK_V2_ZARR_PATH
 
         # cluster aggregate zarr path
         self.BROAD_TENX_CLUSTER_L4_SUM_ZARR_PATH = BROAD_TENX_CLUSTER_L4_SUM_ZARR_PATH
@@ -43,22 +50,30 @@ class BROAD(AutoPathMixIn):
         ids.name = 'cell'
         return ids
 
-    def get_tenx_annot(self):
-        return BROADTENXCellAnnotation(self.BROAD_TENX_CELL_TYPE_ANNOTATION_PATH,
+    def get_tenx_annot(self, version='v2'):
+        if version == 'v2':
+            path = self.BROAD_TENX_CELL_TYPE_V2_ANNOTATION_PATH
+        else:
+            path = self.BROAD_TENX_CELL_TYPE_ANNOTATION_PATH
+        return BROADTENXCellAnnotation(path,
                                        self.get_tenx_sample_metadata())
 
-    def _open_gene_chunk_zarr(self):
+    def _open_gene_chunk_zarr(self, version):
         import xarray as xr
-        self._gene_zarr = xr.open_zarr(self.BROAD_TENX_GENE_CHUNK_ZARR_PATH)
+        if version == 'v2':
+            path = self.BROAD_TENX_GENE_CHUNK_V2_ZARR_PATH
+        else:
+            path = self.BROAD_TENX_GENE_CHUNK_ZARR_PATH
+        self._gene_zarr = xr.open_zarr(path)
         self._cell_million_reads = self._gene_zarr['umi_count'].to_pandas()
         self._cell_million_reads /= 1000000
         self._gene_index = self._gene_zarr.get_index('gene')
         return
 
     @lru_cache(maxsize=200)
-    def get_tenx_gene_data(self, gene, normalize=True, log=True):
+    def get_tenx_gene_data(self, gene, normalize=True, log=True, version='v2'):
         if self._gene_zarr is None:
-            self._open_gene_chunk_zarr()
+            self._open_gene_chunk_zarr(version=version)
 
         # check if gene is gene name:
         if gene in self._gene_index:
